﻿--
-- Ladders for Rolland Trailer Functions
-- 
-- author  Mythos
-- date  07/02/2017
-- www.ARM-team.gr
-- Copyright (C) ARM Team, All Rights Reserved.

Ladders = {};

function Ladders.prerequisitesPresent(specializations)
    return true;
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:load(savegame)
	
	-- Functions
	self.MPCode = SpecializationUtil.callSpecializationsFunction("MPCode");
	
	-- Booleans
	self.LF = true;
	self.LB = true;
	
	-- Animations
	self.ladderFront = getXMLString(self.xmlFile, "vehicle.ladderFront#animationName");
	self.ladderBack = getXMLString(self.xmlFile, "vehicle.ladderBack#animationName");

end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:delete()
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:mouseEvent(posX, posY, isDown, isUp, button)
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:keyEvent(unicode, sym, modifier, isDown)
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:update(dt)
	
	if self:getIsActiveForInput() and self:getIsActive() then
		
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA4) then
			self:MPCode(1, not self.LF);
		end;
		
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
			self:MPCode(2, not self.LB);
		end;
	
	end;
	
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:updateTick(dt)
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:MPCode(mode, state, a1, noEventSend)
	LaddersEvent.sendEvent(self, mode, state, a1, noEventSend);

--______________________________________________________________________________
	if mode == 1 then
--_____________________________________  FRONT LADDER ______________________________
		if state then
			self:playAnimation(self.ladderFront, -1, nil, true);
			self.LF = true;
		else
			self:playAnimation(self.ladderFront, 1, nil, true);
			self.LF = false;
		end;
--______________________________________________________________________________
	elseif mode == 2 then
--_____________________________________  BACK LADDER _____________________________
		if state then
			self:playAnimation(self.ladderBack, -1, nil, true);
			self.LB = true;
		else
			self:playAnimation(self.ladderBack, 1, nil, true);
			self.LB = false;
		end;
	end;

end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:draw()
	g_currentMission:addHelpButtonText(g_i18n:getText("REMOVE_F"), InputBinding.IMPLEMENT_EXTRA4);
	g_currentMission:addHelpButtonText(g_i18n:getText("REMOVE_B"), InputBinding.IMPLEMENT_EXTRA2);
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:postLoad(savegame)
	if savegame ~= nil and not savegame.resetVehicles then
		self.LF = Utils.getNoNil(getXMLBool(savegame.xmlFile, savegame.key.."#LF"),true);
		self.LB = Utils.getNoNil(getXMLBool(savegame.xmlFile, savegame.key.."#LB"),true);
		
		if not self.LF then
			self:MPCode(1, self.LF);
		end;
		if not self.LB then
			self:MPCode(2, self.LB);
		end;
		
	end;
	
	return BaseMission.VEHICLE_LOAD_OK;
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'LF="'..tostring(self.LF)..
	'" LB="'..tostring(self.LB)..'"';

	local nodes = nil;
	
	return attributes,nodes;
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:readStream(streamId, connection)
	self.LF = streamReadBool(streamId);
	self.LB = streamReadBool(streamId);
	
	self:MPCode(1, self.LF, nil, true);
	self:MPCode(2, self.LB, nil, true);
	
end;

--________________________________________________________________________________________________________________________________________________________
function Ladders:writeStream(streamId, connection)
	streamWriteBool(streamId, self.LF);
	streamWriteBool(streamId, self.LB);
end;

--**********************************************************************************************************************************************************************************
LaddersEvent = {};
LaddersEvent_mt = Class(LaddersEvent, Event);

InitEventClass(LaddersEvent, "LaddersEvent");

function LaddersEvent:emptyNew()
    local self = Event:new(LaddersEvent_mt);
    self.className="LaddersEvent";
    return self;
end;

function LaddersEvent:new(vehicle, mode, state, a1)
    local self = LaddersEvent:emptyNew()
    self.vehicle = vehicle;
	self.mode = mode;
	self.state = state;
	self.a1 = a1;
    return self;
end;

function LaddersEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
	self.mode = streamReadInt32(streamId);
	self.state = streamReadBool(streamId);
	self.a1 = streamReadInt32(streamId);
    self.vehicle = networkGetObject(id);
    self:run(connection);
end;

function LaddersEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.vehicle));
	streamWriteInt32(streamId, self.mode);
	streamWriteBool(streamId, self.state);
	streamWriteInt32(streamId, self.a1);
end;

function LaddersEvent:run(connection)
	self.vehicle:MPCode(self.mode, self.state, self.a1, true);
    if not connection:getIsServer() then
        g_server:broadcastEvent(LaddersEvent:new(self.vehicle, self.mode, self.state, self.a1), nil, connection, self.vehicle);
    end;
end;

function LaddersEvent.sendEvent(vehicle, mode, state, a1, noEventSend)
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then
			g_server:broadcastEvent(LaddersEvent:new(vehicle, mode, state, a1), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(LaddersEvent:new(vehicle, mode, state, a1));
		end;
	end;
end;